/* tslint:disable */
/* eslint-disable */
/**
* DFA from JSON string
* Throws when the JSON is invalid
* @param {string} json
* @returns {DfaJson}
*/
export function dfaFromJson(json: string): DfaJson;
/**
* NFA from JSON string
* Throws when the JSON is invalid
* @param {string} json
* @returns {NfaJson}
*/
export function nfaFromJson(json: string): NfaJson;
/**
* Convert DFA to mermaid graph
* @param {DfaJson} dfa
* @returns {string}
*/
export function dfaToMermaid(dfa: DfaJson): string;
/**
* Convert NFA to mermaid graph
* @param {NfaJson} nfa
* @returns {string}
*/
export function nfaToMermaid(nfa: NfaJson): string;
/**
* Construct NFA from regular expression
* and return the JSON representation
* Throws when the regular expression is invalid
* We only support the following syntax:
* ```txt
* <regex> ::= <term> '|' <regex> | <term>
* <term> ::= <factor> <term> | <factor>
* <factor> ::= <base> '*' | <base>
* <base> ::= <char> | '(' <regex> ')'
* ```
* @param {string} reg
* @returns {NfaJson}
*/
export function regexToNfa(reg: string): NfaJson;
/**
* Convert NFA to DFA
* @param {NfaJson} nfa
* @returns {NfaToDfaResult}
*/
export function nfaToDfa(nfa: NfaJson): NfaToDfaResult;
/**
* Regex -> NFA -> DFA
* @param {string} reg
* @returns {DfaJson}
*/
export function regexToDfa(reg: string): DfaJson;
/**
* Minimize DFA
* @param {DfaJson} dfa
* @returns {MinimizeResult}
*/
export function minimizeDfa(dfa: DfaJson): MinimizeResult;
/**
* Regex -> NFA -> DFA -> Minimized DFA
* @param {string} reg
* @returns {DfaJson}
*/
export function regexToMinDfa(reg: string): DfaJson;
/**
* Test if the input string is accepted by the DFA
* Returns true if accepted, false otherwise
* @param {DfaJson} dfa
* @param {string} input
* @returns {boolean}
*/
export function testDfa(dfa: DfaJson, input: string): boolean;
/**
* Test if the input string is accepted by the NFA
* Returns true if accepted, false otherwise
* @param {NfaJson} nfa
* @param {string} input
* @returns {boolean}
*/
export function testNfa(nfa: NfaJson, input: string): boolean;
export interface DfaJson {
    start: number;
    accept: number[];
    transitions: [number, string, number][];
}

export interface NfaJson {
    start: number;
    accept: number;
    transitions: [number, string | null, number][];
}

export interface NfaToDfaResult {
    dfa: DfaJson;
    markdown: string;
}

export interface MinimizeResult {
    minDfa: DfaJson;
    markdown: string;
}

